@@ -4,7 +4,7 @@
 import pandas as pd
 import numpy as np
 
-df = pd.read_csv(r'data/Final_Project_Raw_Data.csv')
+df = pd.read_csv(r'src/data/Final_Project_Raw_Data.csv')
 
 def count_ripper(data_frame, column_name, brewery_name):
     individual_brewery = data_frame.loc[(data_frame[column_name] == brewery_name)]
